[−][src]Crate wasm_thread
Structs
| Builder | Thread factory, which can be used in order to configure the properties of a new thread. |
| JoinHandle | An owned permission to join on a thread (block on its termination). |
| Thread | A handle to a thread. |
Functions
| __wasm_bindgen_generated_wasm_thread_entry_point | Entry point for web workers |
| current | Gets a handle to the thread that invokes it. |
| get_wasm_bindgen_shim_script_path | Extracts path of the |
| get_worker_script | Generates worker entry script as URL encoded blob |
| sleep | Puts the current thread to sleep for at least the specified amount of time. |
| spawn | Spawns a new thread, returning a JoinHandle for it. |
| wasm_thread_entry_point | Entry point for web workers |
Type Definitions
| Result | A specialized |